==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebGridPinningActionsDescriptionModule.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, markType } from "./type";
import { WebGridActionsBaseDirectiveDescriptionModule } from "./WebGridActionsBaseDirectiveDescriptionModule";
import { WebGridPinningActionsDescriptionMetadata } from "./WebGridPinningActionsDescriptionMetadata";
/**
 * @hidden
 */
var WebGridPinningActionsDescriptionModule = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebGridPinningActionsDescriptionModule, _super);
    function WebGridPinningActionsDescriptionModule() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridPinningActionsDescriptionModule.register = function (a) {
        WebGridActionsBaseDirectiveDescriptionModule.register(a);
        WebGridPinningActionsDescriptionMetadata.d(a);
    };
    WebGridPinningActionsDescriptionModule.$t = markType(WebGridPinningActionsDescriptionModule, 'WebGridPinningActionsDescriptionModule');
    return WebGridPinningActionsDescriptionModule;
}(Base));
export { WebGridPinningActionsDescriptionModule };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebGridPinningActionsDescriptionModule.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, markType } from "./type";
import { WebGridActionsBaseDirectiveDescriptionModule } from "./WebGridActionsBaseDirectiveDescriptionModule";
import { WebGridPinningActionsDescriptionMetadata } from "./WebGridPinningActionsDescriptionMetadata";
/**
 * @hidden
 */
var WebGridPinningActionsDescriptionModule = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridPinningActionsDescriptionModule, _super);
    function WebGridPinningActionsDescriptionModule() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridPinningActionsDescriptionModule.register = function (a) {
        WebGridActionsBaseDirectiveDescriptionModule.register(a);
        WebGridPinningActionsDescriptionMetadata.d(a);
    };
    WebGridPinningActionsDescriptionModule.$t = markType(WebGridPinningActionsDescriptionModule, 'WebGridPinningActionsDescriptionModule');
    return WebGridPinningActionsDescriptionModule;
}(Base));
export { WebGridPinningActionsDescriptionModule };
